@@ -719,7 +719,8 @@ class PullModuleStatusUpdateHandler(IPythonHandler):
             moduleUUIDs = data['moduleUUIDs']
             lastUpdateLines = data['lastUpdateLines']
             lastOutputLines = data['lastOutputLines']
-            response = await IOLoop.current().run_in_executor(None, pull_module_status_updates, workloadUUIDs, moduleUUIDs, lastUpdateLines, lastOutputLines)
+            lastPatches = data['lastPatches']
+            response = await IOLoop.current().run_in_executor(None, pull_module_status_updates, workloadUUIDs, moduleUUIDs, lastUpdateLines, lastOutputLines, lastPatches)
             self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
             self.write(response.read())
             if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
@@ -735,30 +736,6 @@ class PullModuleStatusUpdateHandler(IPythonHandler):
             jupyter_log.error(optumi_start(self) + str(e))
             if DEBUG: raise e
 
-class PushModuleInputHandler(IPythonHandler):
-    @authenticated
-    async def post(self):
-        try:
-            data = json.loads(self.request.body)
-            workloadUUID = data['workloadUUID']
-            moduleUUID = data['moduleUUID']
-            line = data['line']
-            response = await IOLoop.current().run_in_executor(None, push_module_input, workloadUUID, moduleUUID, line)
-            self.set_status(401 if response.geturl().endswith('/login') else response.getcode())
-            self.write(response.read())
-            if response.getcode() >= 300: jupyter_log.info(optumi_start(self) + str(response))
-        except (ConnectionError, URLError) as e:
-            # If we can't connect to the REST interface, we want the extension to treat it as the user being loggeed out
-            self.set_status(401)
-            self.write(json.dumps({'message': str(e)}))
-            jupyter_log.warning(optumi_start(self) + str(e))
-            if DEBUG: raise e
-        except Exception as e:
-            self.set_status(500)
-            self.write(json.dumps({'message': 'Encountered error while pushing module input'}))
-            jupyter_log.error(optumi_start(self) + str(e))
-            if DEBUG: raise e
-
 class SaveNotebookOutputFileHandler(IPythonHandler):
     @authenticated
     async def post(self):
@@ -1034,7 +1011,6 @@ def setup_handlers(server_app):
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/pull-workload-config'), PullWorkloadConfigHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/push-workload-config'), PushWorkloadConfigHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/pull-module-status-updates'), PullModuleStatusUpdateHandler)])
-    web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/push-module-input'), PushModuleInputHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/save-notebook-output-file'), SaveNotebookOutputFileHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-file-download-progress'), GetFileDownloadProgressHandler)])
     web_app.add_handlers(host_pattern, [(url_path_join(base_url, '/optumi/get-total-billing'), GetTotalBillingHandler)])
@@ -1533,7 +1509,7 @@ def pull_workload_status_updates(uuids, lastInitializingLines, lastUploadingLine
     except HTTPError as e:
         return e
 
-def pull_module_status_updates(workloadUUIDs, moduleUUIDs, lastUpdateLines, lastOutputLines):
+def pull_module_status_updates(workloadUUIDs, moduleUUIDs, lastUpdateLines, lastOutputLines, lastPatches):
     URL = get_path() + '/exp/jupyterlab/pull-module-status-updates'
     try:
         form = MultiPartForm()
@@ -1545,22 +1521,8 @@ def pull_module_status_updates(workloadUUIDs, moduleUUIDs, lastUpdateLines, last
             form.add_field('lastUpdateLines', str(lastUpdateLine))
         for lastOutputLine in lastOutputLines:
             form.add_field('lastOutputLines', str(lastOutputLine))
-        data = bytes(form)
-
-        req = request.Request(URL, data=data)
-        req.add_header('Content-type', form.get_content_type())
-        req.add_header('Content-length', len(data))
-        return request.urlopen(req)
-    except HTTPError as e:
-        return e
-
-def push_module_input(workloadUUID, moduleUUID, line):
-    URL = get_path() + '/exp/jupyterlab/push-module-input'
-    try:
-        form = MultiPartForm()
-        form.add_field('workloadUUID', workloadUUID)
-        form.add_field('moduleUUID', moduleUUID)
-        form.add_field('line', line)
+        for lastPatche in lastPatches:
+            form.add_field('lastPatches', str(lastPatche))
         data = bytes(form)
 
         req = request.Request(URL, data=data)
