@@ -16,7 +16,6 @@ import { IntentSlider } from '../core';
 import { FilesPanel } from './deploy/FilesPanel';
 import { ResourcesPanel } from './deploy/resources/ResourcesPanel';
 import { LaunchMode } from './deploy/resources/LaunchMode';
-import ExtraInfo from '../utils/ExtraInfo';
 
 interface IProps {
 	style?: CSSProperties
@@ -36,13 +35,13 @@ export class DeployPage extends React.Component<IProps, IState> {
 	private getValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-		return optumi.metadata.intent;
+		return optumi.config.intent;
 	}
 
 	private async saveValue(intent: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		optumi.metadata.intent = intent;
+		optumi.config.intent = intent;
 		tracker.setMetadata(optumi);
 	}
 
@@ -60,22 +59,29 @@ export class DeployPage extends React.Component<IProps, IState> {
 			<div style={Object.assign({overflow: 'auto'}, this.props.style)}>
 				{((Global.labShell.currentWidget instanceof NotebookPanel) && (Global.tracker.currentWidget != null) && (Global.tracker.currentWidget.context.isReady)) ? (
 					<>
-						<div style={{padding: '6px 20px'}}>
-							<ExtraInfo reminder={Global.tracker.currentWidget.context.path}>
-								<div style={{margin: '6px', opacity: 0.5, fontStyle: 'italic', overflow: 'hidden', textOverflow: 'ellipsis'}}>
-									{'Notebook: ' + Global.tracker.currentWidget.context.path.split('/').pop()}
+						{Global.metadata.getMetadata() == undefined ? (
+							<div style={Object.assign({display: 'flex', flexFlow: 'column', overflow: 'hidden'}, this.props.style)}>
+								<div style={{flexGrow: 1, overflowY: 'auto', padding: '6px'}}>
+									<div style={{ textAlign: 'center', margin: '12px'}}>
+										Fetching configuration...
+									</div>
 								</div>
-							</ExtraInfo>
-							<FilesPanel openUserDialogTo={this.props.openUserDialogTo} />
-							<LaunchMode />
-							<ResourcesPanel />
-							<IntentSlider
-								color={'#10A0F9'}
-								getValue={this.getValue}
-								saveValue={this.saveValue}
-							/>
-						</div>
-						<PreviewLaunchButton style={{padding: '6px'}}/>
+							</div>
+						) : (
+							<>
+								<div style={{padding: '6px 20px'}}>
+									<FilesPanel openUserDialogTo={this.props.openUserDialogTo} />
+									<LaunchMode />
+									<ResourcesPanel />
+									<IntentSlider
+										color={'#10A0F9'}
+										getValue={this.getValue}
+										saveValue={this.saveValue}
+									/>
+								</div>
+								<PreviewLaunchButton style={{padding: '6px'}}/>
+							</>
+						)}
 					</>
 				) : (
 					<div style={{ textAlign: 'center', padding: "16px" }}>
