@@ -76,7 +76,7 @@ export class MachinesPage extends React.Component<IProps, IState> {
         var machines: JSX.Element[] = new Array();
         for (var i = 0; i < this.state.machines.length; i++) {
             var machine: Machine = this.state.machines[i]
-            if (Global.user.userExpertise >= 2 || Machine.getStateMessage(machine.state) != 'Releasing...') {
+            if (Global.user.userExpertise >= 2 || Machine.getStateMessage(machine.state) != 'Releasing') {
                 machines.push(
                     <div key={machine.uuid} style={{display: 'inline-flex', width: '100%', padding: '6px 0px'}}>
                         {machine.getComponent()}
