@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { Global } from '../Global';
 
-import { App } from '../models/App';
+import { App } from '../models/application/App';
 
 import {
 	Divider,
@@ -18,6 +18,7 @@ import { Header, SubHeader } from '../core';
 
 interface IProps {
 	style?: CSSProperties
+	openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
 }
 
 interface IState {}
@@ -40,7 +41,7 @@ export class MonitorPage extends React.Component<IProps, IState> {
 		});
 		return sorted.map(value => (
 				<div key={value.uuid} style={{padding: '6px 0px 6px 6px'}}>
-					{value.getComponent()}
+					{value.getComponent(this.props.openUserDialogTo)}
 				</div>
 			)
 		);
@@ -58,7 +59,7 @@ export class MonitorPage extends React.Component<IProps, IState> {
 		});
 		return sorted.map(value => (
 				<div key={value.uuid} style={{padding: '6px 0px 6px 6px'}}>
-					{value.getComponent()}
+					{value.getComponent(this.props.openUserDialogTo)}
 				</div>
 			)
 		);
