@@ -10,9 +10,9 @@ import withStyles, { CSSProperties } from '@material-ui/core/styles/withStyles';
 import { TextBox, SubHeader } from '../../core';
 import { OutlinedInput, IconButton, Accordion, AccordionSummary, AccordionDetails, withTheme, Theme } from '@material-ui/core';
 import { Global } from '../../Global';
-import { FileUploadMetadata } from '../../models/FileUploadMetadata';
+import { FileUploadConfig } from '../../models/FileUploadConfig';
 import CloseIcon from '@material-ui/icons/Close'
-import { UploadMetadata } from '../../models/UploadMetadata';
+import { UploadConfig } from '../../models/UploadConfig';
 import FileServerUtils from '../../utils/FileServerUtils';
 import { OptumiMetadataTracker } from '../../models/OptumiMetadataTracker';
 import { AddFilesPopup } from './AddFilesPopup';
@@ -20,11 +20,12 @@ import DirListingItemIcon from './fileBrowser/DirListingItemIcon';
 import { FileMetadata } from './fileBrowser/FileBrowser';
 import { DataConnectorMetadata } from './dataConnectorBrowser/DataConnectorBrowser';
 import { AddDataConnectorsPopup } from './AddDataConnectorsPopup';
-import { DataConnectorUploadMetadata } from '../../models/DataConnectorUploadMetadata';
+import { DataConnectorUploadConfig } from '../../models/DataConnectorUploadConfig';
 
 import { ServerConnection } from '@jupyterlab/services';
-import DataConnectorDirListingItemIcon, { DataService } from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
+import DataConnectorDirListingItemIcon from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
 import { ExpandMore, WarningRounded } from '@material-ui/icons';
+import { NotificationsPopup } from './NotificationsPopup';
 
 // const emDirNotFile = 'Path is a directory, not a file'
 // const emDupPath = 'Duplicate file or directory'
@@ -125,14 +126,14 @@ class FilesPanel extends React.Component<IProps, IState> {
     private getRequirementsValue = () => {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const uploads: UploadMetadata = optumi.metadata.upload;
+        const uploads: UploadConfig = optumi.config.upload;
         return uploads.requirements;
     }
 
     private saveRequirements = (value: string): string => {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const uploads: UploadMetadata = optumi.metadata.upload;
+        const uploads: UploadConfig = optumi.config.upload;
         uploads.requirements = value;
         tracker.setMetadata(optumi);
         return '';
@@ -141,7 +142,7 @@ class FilesPanel extends React.Component<IProps, IState> {
     private pathHasError = (path: string): boolean => {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const upload: UploadMetadata = optumi.metadata.upload;
+        const upload: UploadConfig = optumi.config.upload;
         const files = upload.files;
         for (var i = 0; i < files.length; i++) {
             if (files[i].path === path) return true;
@@ -152,7 +153,7 @@ class FilesPanel extends React.Component<IProps, IState> {
     private nameHasError = (name: string): boolean => {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const upload: UploadMetadata = optumi.metadata.upload;
+        const upload: UploadConfig = optumi.config.upload;
         const dataConnectors = upload.dataConnectors;
         for (var i = 0; i < dataConnectors.length; i++) {
             if (dataConnectors[i].name === name) return true;
@@ -162,24 +163,22 @@ class FilesPanel extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        const files = Global.metadata.getMetadata().metadata.upload.files;
-        const dataConnectors = Global.metadata.getMetadata().metadata.upload.dataConnectors;
+        const optumi = Global.metadata.getMetadata().config;
+        const files = optumi.upload.files;
+        const dataConnectors = optumi.upload.dataConnectors;
         return (
             <div style={this.props.style}>
                 <StyledAccordion
                     variant={'outlined'}
                     expanded={this.state.packagesExpanded}
-                    onChange={() => this.safeSetState({packagesExpanded: !this.state.packagesExpanded})}
                     style={{background: 'var(--jp-layout-color1)'}}
                 >
-                    <StyledAccordionSummary
-                        expandIcon={<ExpandMore />}
-                    >
+                    <StyledAccordionSummary style={{cursor: 'default'}}>
                         <SubHeader title='Packages' />
                         <span style={{
-                            margin: 'auto',
+                            margin: 'auto 15px',
                             flexGrow: 1,
-                            textAlign: 'center',
+                            textAlign: 'end',
                             opacity: this.state.packagesExpanded ? 0 : 0.5,
                             transitionDuration: '217ms',
                             whiteSpace: 'nowrap',
@@ -187,17 +186,24 @@ class FilesPanel extends React.Component<IProps, IState> {
                             fontStyle: 'italic',
                         }}>
                             {(() => {
-                                const requirements = Global.metadata.getMetadata().metadata.upload.requirements
+                                const requirements = optumi.upload.requirements
                                 const numRequirements = requirements === '' ? 0 : requirements.split('\n').filter(line => line !== '').length
                                 if (numRequirements > 0) {
                                     return numRequirements + ' requirement' + (numRequirements > 1 ? 's' : '')
                                 }
                             })()}
                         </span>
+                        <IconButton
+                            onClick={() => this.safeSetState({packagesExpanded: !this.state.packagesExpanded})}
+                            style={{padding: '0px', marginRight: '-3px', width: '30px'}}
+                        >
+                            <ExpandMore />
+                        </IconButton>
                     </StyledAccordionSummary>
                     <StyledAccordionDetails>
                         <div style={{display: 'flex', width: '100%'}}>
                             <TextBox<string>
+                                key={optumi.upload.requirements}
                                 multiline
                                 getValue={this.getRequirementsValue}
                                 saveValue={this.saveRequirements}
@@ -210,18 +216,15 @@ class FilesPanel extends React.Component<IProps, IState> {
                 <StyledAccordion
                     variant={'outlined'}
                     expanded={this.state.filesExpanded}
-                    onChange={() => this.safeSetState({filesExpanded: !this.state.filesExpanded})}
                     style={{background: 'var(--jp-layout-color1)'}}
                 >
-                    <StyledAccordionSummary
-                        expandIcon={<ExpandMore />}
-                    >
+                    <StyledAccordionSummary style={{cursor: 'default'}}>
                         <SubHeader title='Files' />
-                        {(this.state.problemFiles.length > 0 || this.state.problemDataConnectors.length > 0) && <WarningRounded fontSize={'small'} style={{color: this.props.theme.palette.error.main, margin: 'auto'}} />}
+                        {(this.state.problemFiles.length > 0 || this.state.problemDataConnectors.length > 0) && <WarningRounded fontSize={'small'} style={{color: this.props.theme.palette.error.main, marginTop: '4px'}} />}
                         <span style={{
-                            margin: 'auto',
+                            margin: 'auto 15px',
                             flexGrow: 1,
-                            textAlign: 'center',
+                            textAlign: 'end',
                             opacity: this.state.filesExpanded ? 0 : 0.5,
                             transitionDuration: '217ms',
                             whiteSpace: 'nowrap',
@@ -230,6 +233,12 @@ class FilesPanel extends React.Component<IProps, IState> {
                         }}>
                             {files.length > 0 && (files.length + ' upload' + (files.length > 1 ? 's' : ''))}{files.length > 0 && dataConnectors.length > 0 ? ', ' : ''}{dataConnectors.length > 0 && (dataConnectors.length + ' connector' + (dataConnectors.length > 1 ? 's' : ''))}
                         </span>
+                        <IconButton
+                            onClick={() => this.safeSetState({filesExpanded: !this.state.filesExpanded})}
+                            style={{padding: '0px', marginRight: '-3px', width: '30px'}}
+                        >
+                            <ExpandMore />
+                        </IconButton>
                     </StyledAccordionSummary>
                     <StyledAccordionDetails>
                         <div style={{display: 'inline-flex', width: '100%'}}>
@@ -239,16 +248,16 @@ class FilesPanel extends React.Component<IProps, IState> {
                                     if (this.pathHasError(fileModel.path)) continue;
                                     const tracker = Global.metadata
                                     const optumi = tracker.getMetadata()
-                                    var files = optumi.metadata.upload.files
+                                    var files = optumi.config.upload.files
                                     if (fileModel.type != 'directory') {
-                                        files.push(new FileUploadMetadata({
+                                        files.push(new FileUploadConfig({
                                             path: fileModel.path,
                                             type: fileModel.type,
                                             mimetype: fileModel.mimetype,
                                             files: [fileModel.path]
                                         }))
                                     } else {
-                                        files.push(new FileUploadMetadata({
+                                        files.push(new FileUploadConfig({
                                             path: fileModel.path,
                                             type: fileModel.type,
                                             mimetype: fileModel.mimetype,
@@ -265,8 +274,8 @@ class FilesPanel extends React.Component<IProps, IState> {
                                     	if (this.nameHasError(dataConnectorModel.name)) continue;
                                     	const tracker = Global.metadata
                                     	const optumi = tracker.getMetadata()
-                                    	var dataConnectors = optumi.metadata.upload.dataConnectors
-                                    	dataConnectors.push(new DataConnectorUploadMetadata({
+                                    	var dataConnectors = optumi.config.upload.dataConnectors
+                                    	dataConnectors.push(new DataConnectorUploadConfig({
                                         	name: dataConnectorModel.name,
                                         	dataService: dataConnectorModel.dataService,
                                     	}))
@@ -287,14 +296,14 @@ class FilesPanel extends React.Component<IProps, IState> {
                         ) : (
                             <>
                                 {files.map(
-                                    (value: FileUploadMetadata) => (
+                                    (value: FileUploadConfig) => (
                                         <ResourceFile
                                             key={value.path}
                                             file={value}
                                             handleFileDelete={() => {
                                                 const tracker: OptumiMetadataTracker = Global.metadata;
                                                 const optumi = tracker.getMetadata();
-                                                const files = optumi.metadata.upload.files
+                                                const files = optumi.config.upload.files
                                                 for (var i = 0; i < files.length; i++) {
                                                     if (files[i].path === value.path) {
                                                         files.splice(i, 1)
@@ -310,14 +319,14 @@ class FilesPanel extends React.Component<IProps, IState> {
                                     )
                                 )}
                                 {dataConnectors.map(
-                                    (value: DataConnectorUploadMetadata) => (
+                                    (value: DataConnectorUploadConfig) => (
                                         <ResourceDataConnector
                                             key={value.name}
                                             dataConnector={value}
                                             handleFileDelete={() => {
                                                 const tracker: OptumiMetadataTracker = Global.metadata;
                                                 const optumi = tracker.getMetadata();
-                                                const dataConnectors = optumi.metadata.upload.dataConnectors
+                                                const dataConnectors = optumi.config.upload.dataConnectors
                                                 for (var i = 0; i < dataConnectors.length; i++) {
                                                     if (dataConnectors[i].name === value.name) {
                                                         dataConnectors.splice(i, 1)
@@ -336,6 +345,34 @@ class FilesPanel extends React.Component<IProps, IState> {
                         )}
                     </StyledAccordionDetails>
                 </StyledAccordion>
+                <StyledAccordionSummary style={{cursor: 'default'}}>
+                    <SubHeader title='Notifications' />
+                    <span style={{
+                        margin: 'auto 15px',
+                        flexGrow: 1,
+                        textAlign: 'end',
+                        opacity: 0.5,
+                        transitionDuration: '217ms',
+                        whiteSpace: 'nowrap',
+                        fontSize: '12px',
+                        fontStyle: 'italic',
+                    }}>
+                        {(() => {
+                            let numEnabled = 0
+							const config = Global.metadata.getMetadata().config
+                            if (!config.interactive) {
+                                const notifications = config.notifications;
+                                if (notifications.jobStartedSMSEnabled) numEnabled++;
+                                if (notifications.jobFailedSMSEnabled || notifications.jobCompletedSMSEnabled) numEnabled++;
+                                // TODO:JJ This currently does not refresh automatically when Global.user.notificationsEnabled changes, and I wasn't sure how to quickly do this.
+                                if (Global.user.notificationsEnabled && numEnabled > 0) {
+                                    return numEnabled + ' enabled'
+                                }
+                            }
+                        })()}
+                    </span>
+                    <NotificationsPopup disabled={Global.metadata.getMetadata().config.interactive} openUserDialogTo={this.props.openUserDialogTo} />
+                </StyledAccordionSummary>
             </div>
         )
     }
@@ -344,8 +381,8 @@ class FilesPanel extends React.Component<IProps, IState> {
         if (this.refreshingFiles) {
             if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
             setTimeout(this.refreshFiles, 60000);
-            const metadata = Global.metadata.getMetadata();
-            const files = metadata.metadata.upload.files;
+            const optumi = Global.metadata.getMetadata().config;
+            const files = optumi.upload.files;
             for (var file of files) {
                 if (!this.refreshingFiles) break;
                 if (!this.state.problemFiles.includes(file.path)) {
@@ -362,8 +399,8 @@ class FilesPanel extends React.Component<IProps, IState> {
         if (this.refreshingDataConnectors) {
             if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
             setTimeout(this.refreshDataConnectors, 60000);
-            const metadata = Global.metadata.getMetadata();
-            const dataConnectors = metadata.metadata.upload.dataConnectors;
+            const optumi = Global.metadata.getMetadata().config;
+            const dataConnectors = optumi.upload.dataConnectors;
             
             const settings = ServerConnection.makeSettings();
             const url = settings.baseUrl + "optumi/get-data-connectors";
@@ -444,7 +481,7 @@ const ThemedFilesPanel = withTheme(FilesPanel)
 export { ThemedFilesPanel as FilesPanel }
 
 interface RFProps {
-    file: FileUploadMetadata,
+    file: FileUploadConfig,
     handleFileDelete: () => void,
     noLongerExists?: boolean,
 }
@@ -514,10 +551,10 @@ class ResourceFile extends React.Component<RFProps, RFState> {
                         }}
                         title={
                             (this.props.file.path.includes('/') ? (
-`Name: ${this.props.file.path.replace(/^[^\/]*\//g, '')}
+`Name: ${this.props.file.path.split('/').pop()}
 Path: ${this.props.file.path.replace(/\/[^\/]*$/, '')}`
                             ) : (
-`Name: ${this.props.file.path.replace(/^[^\/]*\//g, '')}`
+`Name: ${this.props.file.path.split('/').pop()}`
                             ))
                         }
                     >
@@ -578,7 +615,7 @@ Path: ${this.props.file.path.replace(/\/[^\/]*$/, '')}`
 }
 
 interface RDCProps {
-    dataConnector: DataConnectorUploadMetadata,
+    dataConnector: DataConnectorUploadConfig,
     handleFileDelete: () => void,
     noLongerExists?: boolean,
 }
@@ -640,27 +677,6 @@ class ResourceDataConnector extends React.Component<RDCProps, RDCState> {
                         dataService={this.props.dataConnector.dataService}
                     />
                     <div
-                        title={(() => {
-                            var location = ''
-                            switch (this.props.dataConnector.dataService) {
-                                case DataService.AMAZON_S3:
-                                    location = 's3';
-                                    break;
-                                case DataService.GOOGLE_CLOUD_STORAGE:
-                                    location = 'gcp';
-                                    break;
-                                case DataService.GOOGLE_DRIVE:
-                                    location = 'gdrive';
-                                    break;
-                                case DataService.KAGGLE:
-                                    location = 'kaggle';
-                                    break;
-                                case DataService.WASABI:
-                                    location = 'wasabi';
-                                    break;
-                            }
-                            return 'Files will be accessible in ~/' + location + '/';
-                        })()}
                         style={{
                             margin: 'auto 0px',
                             overflow: 'hidden', 
