@@ -50,7 +50,7 @@ export class GoogleDriveConnectorPopup extends React.Component<IProps, IState> {
                 iconClass='jp-drive-logo'
                 description='Access a Drive file'
                 header='Connect to a Google Drive file using a Service Account.'
-                downloadPath='~/gdrive/'
+                downloadPath=''
                 onClose={this.handleClose}
                 getInfo={() => this.state}
                 getContents={(waiting: boolean) => (
@@ -69,6 +69,7 @@ export class GoogleDriveConnectorPopup extends React.Component<IProps, IState> {
                             saveValue={(value: string) => this.safeSetState({ serviceAccountKey: value })}
                             label='Service Account Key'
                             helperText='The contents of the credentials file generated for your Google Service Account.'
+                            helperLink={{link: 'https://cloud.google.com/iam/docs/service-accounts', text: 'learn more'}}
                             labelWidth={BaseConnectorPopup.LABEL_WIDTH}
                             disabled={waiting}
                             multiline
