@@ -25,7 +25,7 @@ interface IState {
     bucketName: string
     objectKey: string
     accessKeyID: string
-    accessSecretKey: string
+    secretAccessKey: string
 }
 
 const defaultState = {
@@ -33,7 +33,7 @@ const defaultState = {
     bucketName: '',
     objectKey: '',
     accessKeyID: '',
-    accessSecretKey: '',
+    secretAccessKey: '',
 }
 
 export class WasabiConnectorPopup extends React.Component<IProps, IState> {
@@ -57,7 +57,7 @@ export class WasabiConnectorPopup extends React.Component<IProps, IState> {
                 iconClass='jp-wasabi-logo'
                 description='Access a Wasabi bucket'
                 header='Connect to a Wasabi bucket or object.'
-                downloadPath='~/wasabi/'
+                downloadPath=''
                 onClose={this.handleClose}
                 getInfo={() => this.state}
                 getContents={(waiting: boolean) => (
@@ -97,10 +97,10 @@ export class WasabiConnectorPopup extends React.Component<IProps, IState> {
                             required
                         />
                         <TextBox<string>
-                            getValue={() => this.state.accessSecretKey}
-                            saveValue={(value: string) => this.safeSetState({ accessSecretKey: value })}
-                            label='Access Secret Key'
-                            helperText='The Access Secret Key as specified in Wasabi (or S3) documentation.'
+                            getValue={() => this.state.secretAccessKey}
+                            saveValue={(value: string) => this.safeSetState({ secretAccessKey: value })}
+                            label='Secret Access Key'
+                            helperText='The Secret Access Key as specified in Wasabi (or S3) documentation.'
                             labelWidth={BaseConnectorPopup.LABEL_WIDTH}
                             disabled={waiting}
                             required
