@@ -7,12 +7,14 @@
 
 import * as React from 'react'
 import DirListingItemIcon from './DirListingItemIcon'
-import { FileMetadata } from './FileBrowser'
 import moment from 'moment'
 import { Global } from '../../../Global';
+import { FilterableFile } from './DirListingContent';
+import { StringExt } from '@lumino/algorithm';
 
 interface IProps {
-    file: FileMetadata
+    file: FilterableFile
+    filter: string
     selected: boolean
     onClick: (event: React.MouseEvent<HTMLLIElement, MouseEvent>) => void
     onDoubleClick: (event: React.MouseEvent<HTMLLIElement, MouseEvent>) => void
@@ -39,8 +41,9 @@ export default class DirListingItem extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        const file = this.props.file
+        const file = this.props.file.file
         const path = file.path.replace(file.name, '').replace(/\/$/, '')
+        const html = StringExt.highlight(file.name, this.props.file.indices, (s: string) => '<mark style="padding: 0px;">' + s + '</mark>').join('');
         return (
             <li
                 className={'jp-DirListing-item' + (this.props.selected ? ' jp-mod-selected' : '')}
@@ -55,9 +58,7 @@ Modified: ${moment(file.last_modified).format('YYYY-MM-DD hh:mm:ss')}
 Writable: ${file.writable}`}
             >
                 <DirListingItemIcon fileType={file.type} mimetype={file.mimetype} />
-                <span className='jp-DirListing-itemText'>
-                    {file.name}
-                </span>
+                <span className='jp-DirListing-itemText' dangerouslySetInnerHTML={{ __html: html }}/>
                 <span
                     className='jp-DirListing-itemModified'
                     title={moment(file.last_modified).format('MMM D, YYYY h:mm A')}
