@@ -8,7 +8,7 @@
 import * as React from 'react';
 import { Global } from '../../../Global';
 
-import { ComputeMetadata } from '../../../models/ComputeMetadata';
+import { ComputeConfig } from '../../../models/ComputeConfig';
 import { User } from '../../../models/User';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import { Slider } from '../../../core';
@@ -25,14 +25,14 @@ export class ComputeComponent extends React.Component<IProps, IState> {
     private getCoresValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
 		return compute.cores[1];
 	}
 
 	private async saveCoresValue(cores: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
         compute.cores = [-1, cores, -1];
 		tracker.setMetadata(optumi);
     }
@@ -40,14 +40,14 @@ export class ComputeComponent extends React.Component<IProps, IState> {
     private getScoreValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
 		return compute.score[1];
 	}
 
 	private async saveScoreValue(score: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
         compute.score = [-1, score, -1];
 		tracker.setMetadata(optumi);
 	}
@@ -55,14 +55,14 @@ export class ComputeComponent extends React.Component<IProps, IState> {
     private getFrequencyValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
 		return compute.frequency[1];
 	}
 
 	private async saveFrequencyValue(frequency: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-		const compute: ComputeMetadata = optumi.metadata.compute;
+		const compute: ComputeConfig = optumi.config.compute;
         compute.frequency = [-1, frequency, -1];
 		tracker.setMetadata(optumi);
 	}
