@@ -9,7 +9,7 @@ import * as React from 'react';
 import { Global } from '../../../Global';
 
 import { Slider } from '../../../core';
-import { GraphicsMetadata } from '../../../models/GraphicsMetadata';
+import { GraphicsConfig } from '../../../models/GraphicsConfig';
 import { User } from '../../../models/User';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import FormatUtils from '../../../utils/FormatUtils';
@@ -25,14 +25,14 @@ export class GraphicsComponent extends React.Component<IProps, IState> {
     private getCoresValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         return graphics.cores[1];
     }
 
     private async saveCoresValue(cores: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.cores = [-1, cores, -1];
         tracker.setMetadata(optumi);
     }
@@ -40,14 +40,14 @@ export class GraphicsComponent extends React.Component<IProps, IState> {
     private getScoreValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         return graphics.score[1];
     }
     
     private async saveScoreValue(score: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.score = [-1, score, -1];
         tracker.setMetadata(optumi);
     }
@@ -55,14 +55,14 @@ export class GraphicsComponent extends React.Component<IProps, IState> {
     private getFrequencyValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         return graphics.frequency[1];
     }
     
     private async saveFrequencyValue(frequency: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.frequency = [-1, frequency, -1];
         tracker.setMetadata(optumi);
     }
@@ -70,14 +70,14 @@ export class GraphicsComponent extends React.Component<IProps, IState> {
     private getMemoryValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         return graphics.memory[1];
     }
     
     private async saveMemoryValue(memory: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.memory = [-1, memory, -1];
         tracker.setMetadata(optumi);
     }
