@@ -24,13 +24,13 @@ export class LaunchMode extends React.Component<IProps, IState> {
     private getValue(): string {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-        return optumi.metadata.interactive ? "Session" : "Job";
+        return optumi.config.interactive ? "Session" : "Job";
 	}
 
 	private saveValue(value: string) {
         const tracker: OptumiMetadataTracker = Global.metadata;
 		const optumi = tracker.getMetadata();
-        optumi.metadata.interactive = value == "Session" ? true : false;
+        optumi.config.interactive = value == "Session" ? true : false;
         tracker.setMetadata(optumi);
     }
 
