@@ -9,7 +9,7 @@ import * as React from 'react';
 import { Global } from '../../../Global';
 
 import { Slider } from '../../../core';
-import { MemoryMetadata } from '../../../models/MemoryMetadata';
+import { MemoryConfig } from '../../../models/MemoryConfig';
 import { User } from '../../../models/User';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import FormatUtils from '../../../utils/FormatUtils';
@@ -25,14 +25,14 @@ export class MemoryComponent extends React.Component<IProps, IState> {
     private getSizeValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const memory: MemoryMetadata = optumi.metadata.memory;
+        const memory: MemoryConfig = optumi.config.memory;
         return memory.size[1];
     }
     
     private async saveSizeValue(size: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const memory: MemoryMetadata = optumi.metadata.memory;
+        const memory: MemoryConfig = optumi.config.memory;
         memory.size = [-1, size, -1];
         tracker.setMetadata(optumi);
     }
