@@ -29,11 +29,11 @@ import { MemoryComponent } from './MemoryComponent';
 import { StorageBasic } from './StorageBasic';
 import { StorageComponent } from './StorageComponent';
 import { StorageRating } from './StorageRating';
-import { StorageMetadata } from '../../../models/StorageMetadata';
-import { Expertise } from '../../../models/OptumiMetadata';
-import { ComputeMetadata } from '../../../models/ComputeMetadata';
-import { GraphicsMetadata } from '../../../models/GraphicsMetadata';
-import { MemoryMetadata } from '../../../models/MemoryMetadata';
+import { StorageConfig } from '../../../models/StorageConfig';
+import { Expertise } from '../../../models/OptumiConfig';
+import { ComputeConfig } from '../../../models/ComputeConfig';
+import { GraphicsConfig } from '../../../models/GraphicsConfig';
+import { MemoryConfig } from '../../../models/MemoryConfig';
 import { Basic } from './Basic';
 
 interface IProps {
@@ -46,52 +46,52 @@ export class ResourcesPanel extends React.Component<IProps, IState> {
 
     private getGraphicsLevel(tracker: OptumiMetadataTracker): Expertise {
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         return graphics.expertise;
     }
 
     private async saveGraphicsLevel(tracker: OptumiMetadataTracker, expertise: Expertise) {
         const optumi = tracker.getMetadata();
-        const graphics: GraphicsMetadata = optumi.metadata.graphics;
+        const graphics: GraphicsConfig = optumi.config.graphics;
         graphics.expertise = expertise;
         tracker.setMetadata(optumi);
     }
 
     private getComputeLevel(tracker: OptumiMetadataTracker): Expertise {
         const optumi = tracker.getMetadata();
-        const compute: ComputeMetadata = optumi.metadata.compute;
+        const compute: ComputeConfig = optumi.config.compute;
         return compute.expertise;
     }
 
     private async saveComputeLevel(tracker: OptumiMetadataTracker, expertise: Expertise) {
         const optumi = tracker.getMetadata();
-        const compute: ComputeMetadata = optumi.metadata.compute;
+        const compute: ComputeConfig = optumi.config.compute;
         compute.expertise = expertise;
         tracker.setMetadata(optumi);
     }
 
     private getMemoryLevel(tracker: OptumiMetadataTracker): Expertise {
         const optumi = tracker.getMetadata();
-        const memory: MemoryMetadata = optumi.metadata.memory;
+        const memory: MemoryConfig = optumi.config.memory;
         return memory.expertise;
     }
 
     private async saveMemoryLevel(tracker: OptumiMetadataTracker, expertise: Expertise) {
         const optumi = tracker.getMetadata();
-        const memory: MemoryMetadata = optumi.metadata.memory;
+        const memory: MemoryConfig = optumi.config.memory;
         memory.expertise = expertise;
         tracker.setMetadata(optumi);
     }
 
     private getStorageLevel(tracker: OptumiMetadataTracker): Expertise {
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         return storage.expertise;
     }
 
     private async saveStorageLevel(tracker: OptumiMetadataTracker, expertise: Expertise) {
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         storage.expertise = expertise;
         tracker.setMetadata(optumi);
     }
