@@ -10,7 +10,7 @@ import { Global } from '../../../Global';
 
 import { Slider } from '../../../core';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
-import { StorageMetadata } from '../../../models/StorageMetadata';
+import { StorageConfig } from '../../../models/StorageConfig';
 import { User } from '../../../models/User';
 import FormatUtils from '../../../utils/FormatUtils';
 
@@ -25,7 +25,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
     private getSizeValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         return storage.size[1];
         return 20
     }
@@ -33,7 +33,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
     private async saveSizeValue(size: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         storage.size = [-1, size, -1];
         tracker.setMetadata(optumi);
     }
@@ -41,7 +41,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
     private getIopsValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         return storage.iops[1];
         return 20
     }
@@ -49,7 +49,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
     private async saveIopsValue(iops: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         storage.iops = [-1, iops, -1];
         tracker.setMetadata(optumi);
     }
@@ -57,7 +57,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
     private getThroughputValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         return storage.throughput[1];
         return 20
     }
@@ -65,7 +65,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
     private async saveThroughputValue(throughput: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         storage.throughput = [-1, throughput, -1];
         tracker.setMetadata(optumi);
     }
