@@ -10,7 +10,7 @@ import { Global } from '../../../Global';
 
 import { Slider } from '../../../core';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
-import { StorageMetadata } from '../../../models/StorageMetadata';
+import { StorageConfig } from '../../../models/StorageConfig';
 import FormatUtils from '../../../utils/FormatUtils';
 
 interface IProps {
@@ -24,14 +24,14 @@ export class StorageRating extends React.Component<IProps, IState> {
     private getValue(): number {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         return storage.rating[1];
     }
     
     private async saveValue(rating: number) {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const storage: StorageMetadata = optumi.metadata.storage;
+        const storage: StorageConfig = optumi.config.storage;
         storage.rating = [-1, rating, -1];
         tracker.setMetadata(optumi);
     }
