@@ -18,9 +18,10 @@ import { ServerConnection } from '@jupyterlab/services';
 import { DataConnectorIdentity } from '../components/deploy/DataConnectorIdentity'
 import { DataService } from '../components/deploy/dataConnectorBrowser/DataConnectorDirListingItemIcon';
 import { NotebookPanel } from '@jupyterlab/notebook';
-import { DataConnectorUploadMetadata } from '../models/DataConnectorUploadMetadata';
+import { DataConnectorUploadConfig } from '../models/DataConnectorUploadConfig';
 import { OptumiMetadataTracker } from '../models/OptumiMetadataTracker';
-import { UploadMetadata } from '../models/UploadMetadata';
+import { UploadConfig } from '../models/UploadConfig';
+import ExtraInfo from '../utils/ExtraInfo';
 
 const StyledDialog = withStyles({
     paper: {
@@ -77,7 +78,7 @@ const defaultState = {
 export class BaseConnectorPopup extends React.Component<IProps, IState> {
     _isMounted = false;
 
-    static LABEL_WIDTH = '136px'
+    static LABEL_WIDTH = '144px'
 
     constructor(props: IProps) {
         super(props);
@@ -98,7 +99,7 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
     private nameHasError = (name: string): boolean => {
         const tracker: OptumiMetadataTracker = Global.metadata;
         const optumi = tracker.getMetadata();
-        const upload: UploadMetadata = optumi.metadata.upload;
+        const upload: UploadConfig = optumi.config.upload;
         const dataConnectors = upload.dataConnectors;
         for (var i = 0; i < dataConnectors.length; i++) {
             if (dataConnectors[i].name === name) return true;
@@ -138,8 +139,8 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
             if (add && !this.nameHasError(this.state.name)) {
                 const tracker = Global.metadata
                 const optumi = tracker.getMetadata()
-                var dataConnectors = optumi.metadata.upload.dataConnectors
-                dataConnectors.push(new DataConnectorUploadMetadata({
+                var dataConnectors = optumi.config.upload.dataConnectors
+                dataConnectors.push(new DataConnectorUploadConfig({
                     name: this.state.name,
                     dataService: this.props.dataService,
                 }))
@@ -221,23 +222,25 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                             >
                                 {this.state.waiting && this.state.createSpinning ? <CircularProgress size='1.75em' /> : 'Create'}
                             </Button>
-                            <Button
-                                disableElevation
-                                style={{ margin: '6px', height: '36px' }}
-                                variant='contained'
-                                color='primary'
-                                onClick={() => this.handleCreate(true)}
-                                disabled={(!(Global.labShell.currentWidget instanceof NotebookPanel) && Global.tracker.currentWidget != null) || this.state.waiting}
-                            >
-                                {this.state.waiting && this.state.addSpinning ? <CircularProgress size='1.75em' /> : 'Create and add to notebook'}
-                            </Button>
+                            <ExtraInfo reminder='Create and add to your notebook' >
+                                <Button
+                                    disableElevation
+                                    style={{ margin: '6px', height: '36px' }}
+                                    variant='contained'
+                                    color='primary'
+                                    onClick={() => this.handleCreate(true)}
+                                    disabled={(!(Global.labShell.currentWidget instanceof NotebookPanel) && Global.tracker.currentWidget != null) || this.state.waiting}
+                                >
+                                    {this.state.waiting && this.state.addSpinning ? <CircularProgress size='1.75em' /> : 'Create + Add'}
+                                </Button>
+                            </ExtraInfo>
                         </div>
                     </MuiDialogTitle>
                     <ShadowedDivider />
-                    <DialogContent style={{ padding: '0px' }}>
-                        <div style={{ padding: '12px' }}>
+                    <DialogContent style={{ padding: '0px', display: 'flex' }}>
+                        <div style={{ padding: '12px', display: 'flex', flexDirection: 'column' }}>
                             <div style={{ margin: '12px 18px 18px 18px' }}>
-                                {this.props.header}
+                                {this.props.header + " Files from this connector will be accessible in your notebook's working directory."}
                             </div>
                             <TextBox<string>
                                 getValue={() => this.state.name}
@@ -248,25 +251,36 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                                 disabled={this.state.waiting}
                                 required
                             />
-                            <TextBox<string>
+                            {/* <TextBox<string>
                                 getValue={() => this.props.downloadPath}
                                 label='Download Path'
                                 helperText='We will create a directory with this name and place your files in it.'
                                 labelWidth={BaseConnectorPopup.LABEL_WIDTH}
                                 disabled
                                 required
-                            />
+                            /> */}
                             {this.props.getContents(this.state.waiting)}
                             {this.state.errorMessage && (
                                 <div style={{
                                     color: '#f48f8d',
-                                    margin: '12px',
+                                    margin: '36px 12px',
                                     wordBreak: 'break-all',
                                     fontSize: '12px',
                                 }}>
                                     {this.state.errorMessage}
                                 </div>
                             )}
+                            <div style={{flexGrow: 1}}/>
+                            <div style={{
+                                margin: '12px 18px',
+                                fontStyle: 'italic',
+                                fontSize: '14px',
+                                textAlign: 'end',
+                                // TODO:Beck how do I do this with the theme
+                                color: 'gray'
+                            }}>
+                                *required fields
+                            </div>
                         </div>
                     </DialogContent>
                 </StyledDialog>
