@@ -9,7 +9,6 @@ import * as React from 'react';
 import { Global } from '../Global';
 import { Slider, withStyles, darken, lighten } from '@material-ui/core';
 import { Eco, Equalizer, FlashOn } from '@material-ui/icons';
-import { SubHeader } from './Header';
 
 interface IProps {
     getValue: () => number
@@ -161,8 +160,7 @@ export class IntentSlider extends React.Component<IProps, IState> {
         const icon = this.state.value < 0.33 ? 0 : this.state.value < 0.66 ? 1 : 2
         return (
             <div style={this.props.style}>
-                <SubHeader title='Resource Tradeoff'/>
-                <div style={{position: 'relative', margin: '0px 6px'}}>
+                <div style={{position: 'relative', margin: '3px 6px'}}>
                     <this.StyledSlider
                         // style={{position: 'relative'}}
                         onChange={this.handleChange}
@@ -189,7 +187,7 @@ export class IntentSlider extends React.Component<IProps, IState> {
                             height: '0px', overflow: 'visible', pointerEvents: 'none' // Pass click events to the slider behind
                         }}
                     >
-                        {'< Cheaper'}
+                        {'Cheaper'}
                     </div>
                     <div style={{
                             position: 'absolute',
@@ -204,7 +202,7 @@ export class IntentSlider extends React.Component<IProps, IState> {
                             height: '0px', overflow: 'visible', pointerEvents: 'none' // Pass click events to the slider behind    
                         }}
                     >
-                        {'Faster >'}
+                        {'Faster'}
                     </div>
                 </div>
             </div>
