@@ -19,6 +19,7 @@ interface IProps {
     labelWidth?: string
     flip?: boolean
     ref?: any
+    disabled?: boolean
     onMouseOver?: (...args: any[]) => any
     onMouseOut?: (...args: any[]) => any
 }
@@ -94,6 +95,7 @@ export class Switch extends React.Component<IProps, IState> {
                                 this.safeSetState({value: event.currentTarget.checked})
                                 this.props.saveValue(event.currentTarget.checked)
                             }}
+                            disabled={this.props.disabled}
                         />
                     </div>
                 </ExtraInfo>
