@@ -5,7 +5,6 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-export { FullWidthTextBox } from './FullWidthTextBox'
 export { Header, SubHeader } from './Header'
 export { IntentSlider } from './IntentSlider'
 export { Label } from './Label'
@@ -13,4 +12,5 @@ export { ShadowedDivider } from './ShadowedDivider'
 export { Slider } from './Slider'
 export { Switch } from './Switch'
 export { TextBox } from './TextBox'
-export { TextBoxDropdown } from './TextBoxDropdown'
\ No newline at end of file
+export { TextBoxDropdown } from './TextBoxDropdown'
+export { Dropdown } from './Dropdown'
