@@ -42,6 +42,9 @@ export default class Notebook extends React.Component<IProps, IState> {
     }
 
     public componentDidMount = () => {
+        // Scroll to the current executing cell if there is one running
+        location.href = "#";
+        location.href = "#scrollHere";
         // Override the JupyterLab context menu open (disable it)
         this.oldOpen = Global.lab.contextMenu.open;
         Global.lab.contextMenu.open = () => false;
@@ -52,4 +55,15 @@ export default class Notebook extends React.Component<IProps, IState> {
         // Restore the old JupyterLab context menu open
         Global.lab.contextMenu.open = this.oldOpen;
     }
+
+    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+        try {
+            if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
+            if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
+            return false;
+        } catch (error) {
+            return true;
+        }
+    }
 }
