@@ -24,13 +24,15 @@ import { Update } from '../Update';
 import { OutputFile } from '../OutputFile';
 import { Snackbar } from '../Snackbar';
 import FileServerUtils from '../../utils/FileServerUtils';
-import NotebookUtils from '../../utils/NotebookUtils';
 import FormatUtils from '../../utils/FormatUtils';
 
 import { IdentityAppComponent } from './IdentityAppComponent';
 import { AppComponent } from './AppComponent';
 import { PopupAppComponent } from './PopupAppComponent';
 
+import { applyPatch } from 'rfc6902';
+import { NotebookModel } from '@jupyterlab/notebook';
+
 export enum Phase {
 	Initializing = 'initializing',
 	Uploading = 'uploading',
@@ -48,88 +50,12 @@ export class App {
 	private _notebook: any;
 	private _config: OptumiConfig;
 
-	// Callback for module to add output to the notebook
-	private formatForNotebook = (text: string[]) => {
-		// We will not fix overwritten characters in the last line, in case the last line we have wipes out all the characters without writing new ones
-		// We will leave the task of removing backspace characters from the last line to the component that renders the lines
-		var lastLine = text.pop()
-		// Remove overwritten characters and split into lines
-		const formatted = NotebookUtils.fixOverwrittenChars(text).split('\n').map(x => x + '\n')
-		// Remove the extra '\n'
-		formatted[formatted.length-1] = formatted[formatted.length-1].substr(0, formatted[formatted.length-1].length-1);
-		// Add the last line back
-		formatted.push(lastLine);
-		return formatted
+	private applyPatch = (patch: any) => {
+		applyPatch(this._notebook, patch);
 	}
 
-	private addOutput = (line: string, modifier: string) => {
-		// We do not want to add output to the notebook for an interactive session
-		if (!this.interactive) {
-			// TODO:JJ If modifier is input, we can not parse it
-			if (modifier == 'input') return;
-			// TODO:JJ We could get the info that this line is error from either the modifier or the metadata
-			try {
-				const parsed = JSON.parse(line);
-				const metadata = parsed.metadata;
-				const outputs: any[] = this._notebook.cells[metadata.cell].outputs;
-				// Ignore messages for markdown or raw cells
-				if (this._notebook.cells[metadata.cell].cell_type != 'code') return;
-				if (metadata.status) {
-					if (metadata.status == 'started') {
-						this._notebook.cells[metadata.cell].execution_count = '*';
-					} else if (metadata.status == 'ended') {
-						var count = 1;
-						for (let i = 0; i < metadata.cell; i++) {
-							if (this._notebook.cells[i].cell_type == ['code']) count++;
-						}
-						this._notebook.cells[metadata.cell].execution_count = count;
-					}
-				} else {
-					if (modifier == 'output') {
-						// We will write our other status updates to output
-						if (outputs.length == 0 || outputs[outputs.length-1].name != 'stdout') {
-							outputs.push({
-								name: 'stdout',
-								output_type: 'stream',
-								text: this.formatForNotebook([parsed.text]),
-							});
-						} else {
-							const text: string[] = outputs[outputs.length-1].text;
-							text.push(parsed.text);
-							outputs[outputs.length-1].text = this.formatForNotebook(text)
-						}
-					} else if (modifier == 'error') {
-						// This could be a print to stderr (like a log message) or it could be a caught and formatted exception
-						if (parsed.text) {
-							if (outputs.length == 0 || outputs[outputs.length-1].name != 'stderr') {
-								outputs.push({
-									name: 'stderr',
-									output_type: 'stream',
-									text: this.formatForNotebook([parsed.text]),
-								});
-							} else {
-								const text: string[] = outputs[outputs.length-1].text;
-								text.push(parsed.text);
-								outputs[outputs.length-1].text = this.formatForNotebook(text)
-							}
-						} else {
-							outputs.push({
-								"ename": parsed.ename,
-								"evalue": parsed.evalue,
-								"output_type": "error",
-								"traceback": parsed.traceback,
-							});
-						}
-					} else if (modifier == 'input') {
-						// TODO:JJ
-					} else {
-						console.error('Unknown modifier' + modifier);
-					}
-				}
-			} catch (err) {
-				console.warn('Unable to add update line: ' + line);
-			}
-		}
+	private updateNotebook = (notebook: any) => {
+		this._notebook = notebook;
 	}
 
 	private _path: string;
@@ -258,12 +184,36 @@ export class App {
                     files.push(new OutputFile(module.files[i], module.filesmod[i], module.filessize[i]));
                 }
 			}
-			var mod: Module = new Module(module.uuid, appMap.uuid, app.addOutput, module.machine ? Object.setPrototypeOf(module.machine, Machine.prototype) : null, module.token, output, updates, files);
+			var lastPatch: number = 0;
+			if (module.patches != null) {
+				for (let i = 0; i < module.patches.length; i++) {
+					const patch = module.patches[i];
+					try {
+						app.applyPatch(JSON.parse(patch));
+						const n = module.patchesmod[i]
+						if (!isNaN(parseFloat(n)) && isFinite(n)) lastPatch = +n;
+					} catch (err) {
+						if (patch != 'stop') console.warn('Unable to apply patch ' + patch);
+					}
+				}
+			}
+			if (module.notebook != null) {
+				const notebook = module.notebook;
+				try {
+					app.updateNotebook(JSON.parse(notebook));
+					const n = module.patchesmod[0]
+					if (!isNaN(parseFloat(n)) && isFinite(n)) lastPatch = +n;
+				} catch (err) {
+					console.warn('Unable to update notebook ' + notebook);
+				}
+			}
+
+			var mod: Module = new Module(module.uuid, module.machine ? Object.setPrototypeOf(module.machine, Machine.prototype) : null, module.token, output, updates, files, lastPatch);
+			mod.applyPatch = app.applyPatch;
 			app._modules.push(mod);
 			if (mod.modStatus == Status.RUNNING) {
                 // The module is still running
                 if (!app._initializing.completed || !app._uploading.completed || !app._requisitioning.completed || !app._running.completed) {
-                    // Don't poll the module if the app is not running
 					if (app.interactive) mod.startSessionHandler();
                 }
 			}
@@ -293,7 +243,7 @@ export class App {
 				if ((body.requisitioning[i] as string).startsWith('Machine unavailable, trying another')) {
 					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
 					Global.snackbarChange.emit(new Snackbar(
-						this.name + ": " + body.requisitioning[i],
+						this.name + " (" +  this.annotationOrRunNum + "): " + body.requisitioning[i],
 						{ variant: 'warning', }
 					));
 				}
@@ -311,13 +261,13 @@ export class App {
 				if (body.running[i] == 'Completed') {
 					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
 					Global.snackbarChange.emit(new Snackbar(
-						this.name + ": " + body.running[i],
+						this.name + " (" + this.annotationOrRunNum + "): " + body.running[i],
 						{ variant: 'success', }
 					));
 				} else if (body.running[i] == 'Failed') {
 					if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
 					Global.snackbarChange.emit(new Snackbar(
-						this.name + ": " + body.running[i],
+						this.name + " (" + this.annotationOrRunNum + "): " + body.running[i],
 						{ variant: 'error', }
 					));
 				} else if (body.running[i] == 'Terminated') {
@@ -333,7 +283,23 @@ export class App {
 	}
 
 	get notebook(): any {
-		return this._notebook;
+		const copy = JSON.parse(JSON.stringify(this._notebook));
+		// JupyterLab combines lines with \n, but we need to combine them with ''
+		for (var cell of copy.cells) {
+			if (cell.outputs) {
+				for (var output of cell.outputs) {
+					if (output.text) {
+						output.text = (output.text as string[]).join('');
+					}
+				}
+			}
+		}
+		// Let JupyterLab handle the formatting
+		const model = new NotebookModel()
+		model.fromJSON(copy);
+		model.initialize()
+		const formatted = model.toJSON()
+		return formatted
 	}
 
 	get config(): OptumiConfig {
@@ -371,6 +337,10 @@ export class App {
 		return this._path.split('/').pop().replace('.ipynb', '');
 	}
 
+	get annotationOrRunNum(): string {
+		return this.config.annotation == '' ? 'Run #' + this.runNum : this.config.annotation;
+	}
+
 	get uuid(): string {
 		return this._uuid;
 	}
@@ -563,7 +533,9 @@ export class App {
 			if (body) {
 				if (body.status == "Finished") {
 					for (let i = 0; i < body.modules.length; i++) {
-						const mod = new Module(body.modules[i], this._uuid, this.addOutput);
+						const mod = new Module(body.modules[i]);
+						mod.applyPatch = this.applyPatch
+						mod.updateNotebook = this.updateNotebook
 						this._modules.push(mod);
 						if (this.interactive) mod.startSessionHandler();
 					}
@@ -580,7 +552,7 @@ export class App {
 					if (body.snackbar) {
 						if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
 						Global.snackbarChange.emit(new Snackbar(
-                            this.name + ": " + body.snackbar,
+                            this.name + " (" + this.annotationOrRunNum + "): " + body.snackbar,
                             { variant: 'error', }
                         ));
 					}
@@ -886,4 +858,4 @@ export class App {
 	// 	var endTime = app.getEndTime() < yesterday ? app.getEndTime().toLocaleDateString() : app.getEndTime().toLocaleTimeString();
 	// 	return startTime == endTime ? startTime : startTime + " - " + endTime;
 	// };
-}
\ No newline at end of file
+}
