@@ -5,7 +5,7 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Button, Dialog, DialogContent, IconButton, InputAdornment, Tab, Tabs, TextField, withStyles } from '@material-ui/core';
+import { Button, Dialog, DialogContent, IconButton, Tab, Tabs, withStyles } from '@material-ui/core';
 import * as React from 'react';
 import { Global } from '../../Global';
 import PopupIcon from '@material-ui/icons/MoreVert';
@@ -15,7 +15,6 @@ import CloseIcon from '@material-ui/icons/Close';
 import { App } from './App';
 import { ScrollableDiv } from '../../components/monitor/ScrollableDiv';
 import { OutputFileList } from '../../components/deploy/OutputFileList';
-import CodeIcon from '@material-ui/icons/Code';
 import { Status } from '../Module';
 import { MachineCapability } from '../machine/MachineCapabilities';
 import { ShadowedDivider } from '../../core';
@@ -84,17 +83,6 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
         this.safeSetState({ open: false });
         if (this.props.onClose) this.props.onClose()
 	}
-	
-	private handleInputLineChange = (event: React.ChangeEvent<HTMLInputElement>) => {
-        this.safeSetState({ inputLine: event.target.value });
-    }
-
-    private handleKeyDown = (event: React.KeyboardEvent) => {
-        if (event.key == 'Enter') {
-            this.safeSetState({ inputLine: ''}), 
-            this.props.app.modules[0].pushModuleInput(this.state.inputLine);
-        }
-    }
     
     private handleMouseOver = (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => {
         if (this.props.onMouseOver) this.props.onMouseOver(event);
@@ -277,7 +265,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                             }}
                                             value={Page.MACHINE}
                                         />
-                                        {this.props.app.modules.length > 0 && this.props.app.interactive && <Tab
+                                        {this.props.app.modules.length > 0 && /*this.props.app.interactive &&*/ <Tab
                                             label='TERMINAL'
                                             style={{
                                                 padding: '0px',
@@ -347,25 +335,8 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                         />
                                     </div>
                             ) : this.state.selectedPanel == Page.NOTEBOOK ? (
-                                    <div style={{overflow: 'hidden', width: '100%', height: '100%'}}>
-                                        <div style={{width: '100%', height: 'calc(100% - 68px)', overflow: 'auto'}}>
-                                            <Notebook notebook={this.props.app.notebook} />
-                                        </div>
-                                        <div style={{padding: '6px', width: '100%'}}>
-                                                <TextField
-                                                    variant='outlined' 
-                                                    disabled={this.props.app.modules.length > 0 && this.props.app.modules[0].modStatus == Status.COMPLETED}
-                                                    value={this.state.inputLine} 
-                                                    onChange={this.handleInputLineChange} 
-                                                    onKeyDown={this.handleKeyDown}
-                                                    style={{height: '56px', width: '100%'}}
-                                                    InputProps={{startAdornment: 
-                                                        (<InputAdornment position="start">
-                                                            <CodeIcon />
-                                                        </InputAdornment>)
-                                                    }}
-                                                />
-                                            </div>
+                                    <div style={{overflow: 'auto', width: '100%', height: '100%'}}>
+                                        <Notebook notebook={this.props.app.notebook} />
                                     </div>
                                 ) : this.state.selectedPanel == Page.FILES ? (
                                     <div style={{padding: '8px'}}>
