@@ -8,8 +8,8 @@
 import * as React from 'react';
 import { IdentityMachineComponent } from './IdentityMachineComponent';
 import { MachineComponent } from './MachineComponent';
+import { MachinePreviewComponent } from './MachinePreviewComponent';
 import { PopupMachineComponent } from './PopupMachineComponent';
-import { RecommendedMachineComponent } from './RecommendedMachineComponent';
 
 export class Machine {
     computeCores: number = 0
@@ -40,8 +40,8 @@ export class Machine {
         return React.createElement(MachineComponent, {key: this.uuid, machine: this});
     }
 
-    public getRecommendedComponent(order: number): React.CElement<any, RecommendedMachineComponent> {
-        return React.createElement(RecommendedMachineComponent, {key: this.uuid + order, machine: this, order: order});
+    public getPreviewComponent(): React.CElement<any, MachinePreviewComponent> {
+        return React.createElement(MachinePreviewComponent, {key: this.uuid, machine: this});
     }
 
     public getIdentityComponent(): React.CElement<any, IdentityMachineComponent> {
@@ -56,7 +56,7 @@ export class Machine {
         switch (state) {
             case 'requisition requested':
             case 'requisition in progress':
-                return 'Acquiring...'
+                return 'Acquiring'
             case 'requisition completed':
             case 'setup completed':
                 return 'Ready'
@@ -64,7 +64,7 @@ export class Machine {
             case 'sequestration requested':
             case 'sequestration in progress':
             case 'sequestration completed':
-                return 'Releasing...'
+                return 'Releasing'
             case 'unused':
             default:
                 return ''
