@@ -153,13 +153,25 @@ export class MachineComponent extends React.Component<IProps, IState> {
                                         const appAction = app.interactive ? "closed" : "terminated";
                                         // if (app is running) {
                                         if ((app.requisitioning.completed && !app.requisitioning.error) && !app.running.completed) {
-                                            return "Your " + appWord + " '" +  app.name + "' is active on this machine. It will be " + appAction + " if the machine is released."
+                                            return "Your " + appWord + " '" +  app.name + "' (" + app.annotationOrRunNum + ") is active on this machine. It will be " + appAction + " if the machine is released."
                                         } else {
-                                            return "Your " + appWord + " '" +  app.name + "' is waiting for this machine. It will be deleted if the machine is released."
+                                            return "Your " + appWord + " '" +  app.name + "' (" + app.annotationOrRunNum + ") is waiting for this machine. It will be deleted if the machine is released."
+                                        }
+                                    }
+                                }
+                                // TODO:JJ We want to patch a timing hole where the job completes while the popup is open. For now, we will show the stale information instead of an empty popup
+                                for (var app of user.appTracker.finishedJobsOrSessions) {
+                                    if (app.uuid == machine.app) {
+                                        const appWord = app.interactive ? "session" : "job";
+                                        const appAction = app.interactive ? "closed" : "terminated";
+                                        // if (app is running) {
+                                        if ((app.requisitioning.completed && !app.requisitioning.error) && !app.running.completed) {
+                                            return "Your " + appWord + " '" +  app.name + "' (" + app.annotationOrRunNum + ") is active on this machine. It will be " + appAction + " if the machine is released."
+                                        } else {
+                                            return "Your " + appWord + " '" +  app.name + "' (" + app.annotationOrRunNum + ") is waiting for this machine. It will be deleted if the machine is released."
                                         }
                                     }
                                 }
-                                return "";
                             })()}
                             cancel={{
                                 text: `Cancel`,
