@@ -222,7 +222,7 @@ export class PopupMachineComponent extends React.Component<IProps, IState> {
                                         </div>
                                         {placedApp && (
                                             <div style={{ margin: '6px' }}>
-                                                {(placedApp.interactive ? 'Session' : 'Job') + " '" + placedApp.name + "' is " + (((placedApp.requisitioning.completed && !placedApp.requisitioning.error) && !placedApp.running.completed) ? 'running on' : 'waiting for') + ' this machine'}
+                                                {(placedApp.interactive ? 'Session' : 'Job') + " '" + placedApp.name + "' (" + placedApp.annotationOrRunNum + ") is " + (((placedApp.requisitioning.completed && !placedApp.requisitioning.error) && !placedApp.running.completed) ? 'running on' : 'waiting for') + ' this machine'}
                                             </div>
                                         )}
                                     </>
